Documentation
¶
Index ¶
- func AllOf[T any](first, last iterator.ConstIterator[T], f func(iterator.ConstIterator[T]) bool) bool
- func AnyOf[T any](first, last iterator.ConstIterator[T], f func(iterator.ConstIterator[T]) bool) bool
- func Count[T any](first, last iterator.ConstIterator[T], value T, cmp comparator.Comparator[T]) int
- func CountIf[T any](first, last iterator.ConstIterator[T], f func(iterator.ConstIterator[T]) bool) int
- func Find[T any](first, last iterator.ConstIterator[T], value T, cmp comparator.Comparator[T]) iterator.ConstIterator[T]
- func FindIf[T any](first, last iterator.ConstIterator[T], f func(iterator.ConstIterator[T]) bool) iterator.ConstIterator[T]
- func MaxElement[T any](first, last iterator.ConstIterator[T], cmp comparator.Comparator[T]) iterator.ConstIterator[T]
- func MinElement[T any](first, last iterator.ConstIterator[T], cmp comparator.Comparator[T]) iterator.ConstIterator[T]
- func NoneOf[T any](first, last iterator.ConstIterator[T], f func(iterator.ConstIterator[T]) bool) bool
- func Reverse[T any](first, last iterator.BidIterator[T])
- func Swap[T any](a, b iterator.Iterator[T])
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AllOf ¶
func AllOf[T any](first, last iterator.ConstIterator[T], f func(iterator.ConstIterator[T]) bool) bool
AllOf returns whether all of the elements satisfy the function f in range [first, last)
func AnyOf ¶
func AnyOf[T any](first, last iterator.ConstIterator[T], f func(iterator.ConstIterator[T]) bool) bool
AnyOf returns whether any of the elements satisfy the function f in range [first, last)
func Count ¶
func Count[T any](first, last iterator.ConstIterator[T], value T, cmp comparator.Comparator[T]) int
Count returns the number of elements that their value is equal to value in range [first, last)
func CountIf ¶
func CountIf[T any](first, last iterator.ConstIterator[T], f func(iterator.ConstIterator[T]) bool) int
CountIf returns the number of elements are satisfied the function f in range [first, last)
func Find ¶
func Find[T any](first, last iterator.ConstIterator[T], value T, cmp comparator.Comparator[T]) iterator.ConstIterator[T]
Find finds the first element that its value is equal to value in range [first, last), and returns its iterator, or last if not found
func FindIf ¶
func FindIf[T any](first, last iterator.ConstIterator[T], f func(iterator.ConstIterator[T]) bool) iterator.ConstIterator[T]
FindIf finds the first element that is satisfied the function f, and returns its iterator, or last if not found
func MaxElement ¶
func MaxElement[T any](first, last iterator.ConstIterator[T], cmp comparator.Comparator[T]) iterator.ConstIterator[T]
MaxElement returns an Iterator to the largest element in the range [first, last). If several elements in the range are equivalent to the largest element, returns the iterator to the first such element. Returns last if the range is empty.
func MinElement ¶
func MinElement[T any](first, last iterator.ConstIterator[T], cmp comparator.Comparator[T]) iterator.ConstIterator[T]
MinElement returns an Iterator to the smallest element value in the range [first, last). If several elements in the range are equivalent to the smallest element value, returns the iterator to the first such element. Returns last if the range is empty.
func NoneOf ¶
func NoneOf[T any](first, last iterator.ConstIterator[T], f func(iterator.ConstIterator[T]) bool) bool
NoneOf returns whether none of the elements satisfy the function f in range [first, last)
func Reverse ¶
func Reverse[T any](first, last iterator.BidIterator[T])
Reverse reverse the elements in the range [first, last]
Types ¶
This section is empty.