package
Version:
v1.0.5
Opens a new window with list of versions in this module.
Published: May 27, 2026
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
A Gate controls the maximum number of concurrent running and waiting queries.
func New(maxConcurrentQueries int) *Gate
New returns a query gate that limits the number of queries being concurrently executed.
Done releases a single spot int the gate.
Start blocks until the gate has a free spot or the context is done
Source Files
¶
Click to show internal directories.
Click to hide internal directories.