Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Notifier ¶
type Notifier struct {
// contains filtered or unexported fields
}
Notifier is a thread safe struct that can be used to send notification about some event to multiple consumers.
Click to show internal directories.
Click to hide internal directories.