prometheus

package
v1.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 23, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewCounterAsGauge

func NewCounterAsGauge(c metrics.Counter) metrics.Gauge

NewCounterAsGauge returns a Gauge that actually writes the value on an underlying Counter

func NewCounterAsHistogram

func NewCounterAsHistogram(c metrics.Counter) metrics.Histogram

NewCounterAsHistogram returns a Histogram that actually writes the value on an underlying Counter

func NewGaugeAsCounter

func NewGaugeAsCounter(g metrics.Gauge) metrics.Counter

NewGaugeAsCounter returns a Counter that actually writes the value on an underlying Gauge

func NewGaugeAsHistogram

func NewGaugeAsHistogram(g metrics.Gauge) metrics.Histogram

NewGaugeAsHistogram returns a Histogram that actually writes the value on an underlying Gauge

func NewHistogramAsCounter

func NewHistogramAsCounter(h metrics.Histogram) metrics.Counter

NewHistogramAsCounter returns a Counter that actually writes the value on an underlying Histogram

func NewHistogramAsGauge

func NewHistogramAsGauge(h metrics.Histogram) metrics.Gauge

NewHistogramAsGauge returns a Gauge that actually writes the value on an underlying Histogram

Types

type Counter

type Counter struct {
	// contains filtered or unexported fields
}

Counter implements prometheus.Counter, via prometheus CounterVec

func NewCounter

func NewCounter(cv *prometheus.CounterVec) *Counter

NewCounter wraps the CounterVec and returns a usable Counter object

func NewCounterFrom

func NewCounterFrom(opts prometheus.CounterOpts, labelNames []string) *Counter

NewCounterFrom creates a new Counter from a CounterOpts and a list of label names

func (*Counter) Add

func (c *Counter) Add(delta float64)

func (*Counter) With

func (c *Counter) With(labelValues ...string) metrics.Counter

With implements Counter

type Gauge

type Gauge struct {
	// contains filtered or unexported fields
}

Gauge implements prometheus.Gauge, via prometheus GaugeVec

func NewGauge

func NewGauge(gv *prometheus.GaugeVec) *Gauge

NewGauge wraps the GaugeVec and returns a usable Gauge object

func NewGaugeFrom

func NewGaugeFrom(opts prometheus.GaugeOpts, labelNames []string) *Gauge

NewGaugeFrom creates a new Gauge from a GaugeOpts and a list of label names

func (*Gauge) Add

func (g *Gauge) Add(delta float64)

Add implements Gauge

func (*Gauge) Set

func (g *Gauge) Set(value float64)

Set implements Gauge

func (*Gauge) With

func (g *Gauge) With(labelValues ...string) metrics.Gauge

With implements Gauge

type Histogram

type Histogram struct {
	// contains filtered or unexported fields
}

Histogram implements Histogram via a Prometheus HistogramVec. The difference between a Histogram and a Summary is that Histograms require predefined quantile buckets, and can be statistically aggregated.

func NewHistogram

func NewHistogram(hv *prometheus.HistogramVec) *Histogram

NewHistogram wraps the HistogramVec and returns a usable Histogram object.

func NewHistogramFrom

func NewHistogramFrom(opts prometheus.HistogramOpts, labelNames []string) *Histogram

NewHistogramFrom constructs and registers a Prometheus HistogramVec, and returns a usable Histogram object.

func (*Histogram) Observe

func (h *Histogram) Observe(value float64)

Observe implements Histogram.

func (*Histogram) With

func (h *Histogram) With(labelValues ...string) metrics.Histogram

With implements Histogram.

type Summary

type Summary struct {
	// contains filtered or unexported fields
}

Summary implements Histogram, via a Prometheus SummaryVec. The difference between a Summary and a Histogram is that Summaries don't require predefined quantile buckets, but cannot be statistically aggregated.

func NewSummary

func NewSummary(sv *prometheus.SummaryVec) *Summary

NewSummary wraps the SummaryVec and returns a usable Summary object

func NewSummaryFrom

func NewSummaryFrom(opts prometheus.SummaryOpts, labelNames []string) *Summary

NewSummaryFrom constructs and registers a Prometheus SummaryVec, and returns a usable Summary object.

func (*Summary) Observe

func (s *Summary) Observe(value float64)

func (*Summary) With

func (s *Summary) With(labelValues ...string) metrics.Histogram

Directories

Path Synopsis

Jump to