stats

package
v1.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 27, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Timer

type Timer struct {
	// contains filtered or unexported fields
}

A Timer that can be started and stopped and accumulates the total time it was running (the time between Start() and Stop()).

func (*Timer) Duration

func (t *Timer) Duration() float64

Duration returns the duration value of the timer in seconds

func (*Timer) ElapsedTime

func (t *Timer) ElapsedTime() time.Duration

ElapsedTime returns the time that passed since starting the timer

func (*Timer) Start

func (t *Timer) Start() *Timer

Start the timer

func (*Timer) Stop

func (t *Timer) Stop()

Stop the timer

func (*Timer) String

func (t *Timer) String() string

Return a string representation of the timer

type TimerGroup

type TimerGroup struct {
	// contains filtered or unexported fields
}

A TimerGroup represents a group of timers relevant to a single query

func NewTimerGroup

func NewTimerGroup() *TimerGroup

NewTimerGroup returns a new TimerGroup

func (*TimerGroup) GetTimer

func (t *TimerGroup) GetTimer(name fmt.Stringer) *Timer

GetTimer gets (and creates, if necessary) a Timer for a given code section

func (*TimerGroup) String

func (t *TimerGroup) String() string

Return a string representation of a TimerGroup

Jump to