Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DisableVerifications ¶
func DisableVerifications() func()
DisableVerifications unsets `envVerify` and returns a function that can be used to bring the original settings.
func EnableAllVerifications ¶
func EnableAllVerifications() func()
EnableAllVerifications enables verification and returns a function that can be used to bring the original settings.
func EnableVerifications ¶
func EnableVerifications(verification VerificationType) func()
EnableVerifications sets `envVerify` and returns a function that can be used to bring the original settings.
func IsVerificationEnabled ¶
func IsVerificationEnabled(verification VerificationType) bool
Types ¶
type VerificationType ¶
type VerificationType string
Click to show internal directories.
Click to hide internal directories.