verify

package
v1.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 16, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Assert

func Assert(condition bool, msg string, v ...any)

Assert will panic with a given formatted message if the given condition is false.

func DisableVerifications

func DisableVerifications() func()

DisableVerifications unsets `envVerify` and returns a function that can be used to bring the original settings.

func EnableAllVerifications

func EnableAllVerifications() func()

EnableAllVerifications enables verification and returns a function that can be used to bring the original settings.

func EnableVerifications

func EnableVerifications(verification VerificationType) func()

EnableVerifications sets `envVerify` and returns a function that can be used to bring the original settings.

func IsVerificationEnabled

func IsVerificationEnabled(verification VerificationType) bool

func Verify

func Verify(f func())

Verify performs verification if the assertions are enabled. In the default setup running in tests and skipped in the production code.

Types

type VerificationType

type VerificationType string

Jump to